@@ -2,8 +2,8 @@
 /**
     Node splitting and prediction
     *\file Predict.c
-    *\author $Author: hothorn $
-    *\date $Date: 2011-05-06 17:01:10 +0200 (Fri, 06 May 2011) $
+    *\author $Author: thothorn $
+    *\date $Date: 2012-01-26 13:52:15 +0100 (Thu, 26 Jan 2012) $
 */
                 
 #include "party.h"
@@ -376,39 +376,21 @@ void C_predict(SEXP tree, SEXP newinputs, double mincriterion,
     *\param tree a tree
     *\param newinputs an object of class `VariableFrame'
     *\param mincriterion overwrites mincriterion used for tree growing
+    *\param varperm which variable shall be permuted? -1 for no permutation
 */
 
-SEXP R_predict(SEXP tree, SEXP newinputs, SEXP mincriterion) {
-
-    SEXP ans;
-    int nobs;
-    
-    nobs = get_nobs(newinputs);
-    PROTECT(ans = allocVector(VECSXP, nobs));
-    C_predict(tree, newinputs, REAL(mincriterion)[0], 
-              -1, ans);
-    UNPROTECT(1);
-    return(ans);
-}
-
-/**
-    R-Interface to C_predict \n
-    *\param tree a tree
-    *\param newinputs an object of class `VariableFrame'
-    *\param mincriterion overwrites mincriterion used for tree growing
-    *\param varperm which variable shall be permuted?
-*/
-
-SEXP R_predict2(SEXP tree, SEXP newinputs, SEXP mincriterion,
+SEXP R_predict(SEXP tree, SEXP newinputs, SEXP mincriterion,
                SEXP varperm) {
 
     SEXP ans;
     int nobs;
-    
+
     nobs = get_nobs(newinputs);
     PROTECT(ans = allocVector(VECSXP, nobs));
+    GetRNGstate();
     C_predict(tree, newinputs, REAL(mincriterion)[0], 
               INTEGER(varperm)[0], ans);
+    PutRNGstate();
     UNPROTECT(1);
     return(ans);
 }
